@@ -30,14 +30,6 @@
 
 function semilogx (varargin)
 
-  ## XXX FIXME XXX -- these plot states should really just be set
-  ## temporarily, probably inside an unwind_protect block, but there is
-  ## no way to determine their current values.
-
-#  gset logscale x;
-#  gset nologscale y;
-#  gset nopolar;
-
   __plt__ ("semilogx", varargin{:});
 
 endfunction
