@@ -1,4 +1,19 @@
-function [Z,w] = strtoz(s)
+## Copyright (C) 2000-2004 Teemu Ikonen
+##
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+##
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, write to the Free Software
+## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 #function [Z,w] = strtoz(s)
 #
 # Return atomic numbers Z and the corresponding number of elements w  
@@ -22,6 +37,7 @@ function [Z,w] = strtoz(s)
 # Add support for > 9 stoichiometries, 
 # speedup with data in a structure 21.4.2004 - Teemu
 
+function [Z,w] = strtoz(s)
 
 if(isstr(s))
   tabfile = file_in_loadpath("elements_struct.mat");
