@@ -1,4 +1,19 @@
-function write_pdb(p, fname, varargin)
+## Copyright (C) 2001 Teemu Ikonen
+##
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+##
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, write to the Free Software
+## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 #function write_pdb(p, fname[, quick])
 #
 # Writes a pdb struct p (see read_pdb.m) to a pdb-file fname.
@@ -8,6 +23,8 @@ function write_pdb(p, fname, varargin)
 ## Created: 3.8.2001
 ## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
 
+function write_pdb(p, fname, varargin)
+
 if(!is_struct(p)) # || !struct_contains(p, "acoord"))
     error("p must be a pdb struct");
 endif
