@@ -1,3 +1,5 @@
+## Author: Paul Kienzle
+## This program is public domain.
 function tclphoto(name,expr)
   ## grab the colormap and convert it to uchar
   map=floor(256*(1-eps)*colormap);
