@@ -1,3 +1,5 @@
+## Author: Paul Kienzle
+## This program is public domain.
 function tclsend(name, m)
   if isstr(m)
     send(name,m);
