@@ -1,3 +1,20 @@
+## Copyright (C) 2003 Julius O. Smith III
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2, or (at your option)
+## any later version.
+##
+## This program is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  The GNU
+## General Public License has more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with this program; see the file COPYING.  If not, write to the Free
+## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+## 02111-1307, USA.
+
 ## -*- texinfo -*-
 ## @deftypefn {Function File} freqs_plot (@var{w}, @var{h})
 ## Plot the amplitude and phase of the vector @var{h}.
