@@ -23,7 +23,7 @@
 ## See also fields, getfield, setfield, rmfield, isfield, isstruct,
 ## cmpstruct, struct_size. 
 
-## Author:        Etienne Grossmann  <etienne@isr.ist.utl.pt>
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
 ## November 2000: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
 ##     return error rather than trapping to keyboard
 ## March    2002: Etienne
