@@ -1,7 +1,22 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ###key test_vmesh
 ##
 ## Test vmesh.m
 
+## Author:  Etienne Grossmann <etienne@cs.uky.edu>
+
 printf ("test_vmesh : \nDisplay a surface.\n");
 
 R = 41;
