@@ -1,6 +1,18 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
 ##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+
 ## Test that vrml_faces works with "tex" option
-##
+
+## Author:  Etienne Grossmann <etienne@cs.uky.edu>
 1;
 
 ## Tetrahedron : Vertices
