@@ -1,3 +1,16 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ## s = vmesh (x, y, z [, options] ) - Visualize a 3D surface
 ## s = vmesh (z [, options] )
 ##
@@ -48,7 +61,7 @@
 ## "lcol", lc   : Nx3 : Color of the plane(s).          Default = [.7 .7 .7]
 ## "ltran",lt   : Nx1 : Transparency of the plane(s).   Default =        0.3
 
-## Author:        Etienne Grossmann  <etienne@cs.uky.edu>
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
 
 function s = vmesh (x, y, z, varargin)
 
