@@ -1,3 +1,16 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ##  s = vrml_PointLight (...)   - Vrml PointLight node
 ##  
 ##  s is a string of the form :
@@ -20,13 +33,12 @@
 ##
 ## See also : vrml_DirectionalLight
 
-## Author:        Etienne Grossmann  <etienne@isr.ist.utl.pt>
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
 
 function s = vrml_PointLight (varargin)
 
-  h = struct ();
-
-  if nargin, h = leval ("setfields", varargin); end
+if mod(nargin,2) != 0, usage("vrml_PointLight('key',val,...)"); end
+h = struct (varargin{:});
 
 tpl = struct ("ambientIntensity", "%8.3f",\
 	      "intensity",        "%8.3f",\
