@@ -1,3 +1,16 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ##  p = vrml_browse ([s])       - View vrml code s with FreeWRL
 ##      vrml_browse ("-kill")   - Kill the browser
 ##
@@ -24,7 +37,7 @@
 ##           (shows the contents of the topmost window above it). Use
 ##           "-kill".
 ##
-## Author  : Etienne Grossmann   <etienne@isr.ist.utl.pt>
+## Author  : Etienne Grossmann <etienne@cs.uky.edu>
 function p = vrml_browse (varargin)
 
 verbose = 0;
