@@ -1,3 +1,16 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ## s = vrml_faces(x,f,...) - VRML facet object (IndexedFaceSet node)
 ##
 ## x : 3xP   : The 3D points
@@ -50,7 +63,7 @@
 ##
 ## See also: vrml_surf(), vmesh()
 
-## Author:        Etienne Grossmann  <etienne@isr.ist.utl.pt>
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
 function s = vrml_faces (x,f,varargin)
 
   ## mytic; starttime = cputime();
