@@ -1,3 +1,16 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ## s = vrml_flatten (x [, d, w, col]) - A planar surface containing x
 ##
 ## If the points  x  are not coplanar (or not in the affine plane {y|d'*y==w}),
@@ -11,7 +24,7 @@
 ##
 ## s   : string : vrml code representing the planar surface
 
-## Author:        Etienne Grossmann  <etienne@isr.ist.utl.pt>
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
 ## Last modified: Setembro 2002
 
 function s = vrml_flatten (x, d, w, col)
@@ -26,4 +39,4 @@ y = bound_convex (d,w,x);
 Q = columns (y);
 faces = [ones(1,Q-2); 2:Q-1; 3:Q];
 
-s = vrml_faces (y, faces, "col",col);
\ No newline at end of file
+s = vrml_faces (y, faces, "col",col);
