@@ -1,3 +1,16 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ##       v = vrml_frame (t, r, ...)
 ##  
 ## t : 3      Translation                          Default : [0,0,0]
@@ -11,7 +24,7 @@
 ## "hcol"  : 3 or 3x3 : Color of head     (may be stacked vertically) <col>
 ##                                                  
 
-## Author:        Etienne Grossmann  <etienne@isr.ist.utl.pt>
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
 ## Last modified: Setembro 2002
 
 
@@ -62,8 +75,10 @@ if args
   op1 = " col hcol diam scale ";
   op0 = " verbose ";
   s = read_options (leftover_args, "op1",op1,"op0",op0,"default",df,"skipnan",1);
-  [col, hcol, diam, scale, verbose] = \
-      getfields (s, "col","hcol","diam","scale","verbose");
+  col = s.col;
+  hcol = s.hcol;
+  diam = s.diam;
+  scale = s.scale;
 end
 
 ######################################################################
