@@ -1,3 +1,16 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+##
+
 ##  s = vrml_material (dc,ec,tr) - Returns a "material" vrml node
 ##
 ## dc : 3x1 : diffuseColor
@@ -5,7 +18,7 @@
 ##   or 1x1 : use dc as emissiveColor if ec is true.             Default = 0
 ## tr : 1x1 : transparency                                       Default = 0
 ##
-## Author:        Etienne Grossmann  <etienne@isr.ist.utl.pt>
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
 ## Last modified: Setembro 2002
 
 function s = vrml_material (dc, ec, tran,DEF)
