@@ -1,3 +1,15 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+
 ## s = vrml_parallelogram (x,...)
 ##
 ## x : 3 x 3 : Each column is a 3D point. The fourth corner is 
@@ -18,6 +30,9 @@
 ## bcol,  c : 3   :
 ## bemit, e : 1   :
 ## brad,  r : 1   :
+
+## Author: Etienne Grossmann <etienne@cs.uky.edu>
+
 function s = vrml_parallelogram (x, varargin)
 
 col = [0.3,0.4,0.9];
@@ -31,10 +46,9 @@ if nargin > 1
   op1 = " col emit tran balls border bcol btran bemit brad borad bocol boemit ";
   df = tar (col,emit,tran,balls,border,bcol,btran,bemit,brad,borad,bocol,boemit);
   s = read_options (varargin, "op1",op1, "default",df);
-  [col,emit,tran,balls,border,bcol,btran,bemit,brad,borad,bocol,boemit] = \
-      getfields (s,\
-		"col","emit","tran","balls","border","bcol","btran","bemit",\
-		"brad","borad","bocol","boemit");
+  col=s.col; emit=s.emit; tran=s.tran; balls=s.balls; border=s.border;
+  bcol = s.bcol; btran = s.btran; bemit = s.bemit; brad = s.brad;
+  borad = s.borad; bocol = s.bocol; boemit = s.boemit;
 end
 
 if ! isnan (bcol) ||! isnan (brad) || ! isnan (bemit), balls = 1; end
