@@ -1,3 +1,15 @@
+## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+
 ## s = vrml_select_points (x, state) - vrml code for selecting 3D points
 ##
 ## x     : 3 x P  : 3D points
@@ -11,7 +23,7 @@
 ## 
 ## See  select_3D_points()  for complete 3D point selection interface.
 
-## Author : Etienne Grossmann <etienne@isr.ist.utl.pt>
+## Author : Etienne Grossmann <etienne@cs.uky.edu>
 function s = vrml_select_points (x, state, sphere)
 
 P = columns (x);
